Summary: The most commonly-used entries in the /dev directory.
Name: dev
Version: 2.7.20
Release: 3tr
License: public domain
Group: Trustix Official
Source0: dev-%{PACKAGE_VERSION}.tar.gz
Source1: cciss.tar.gz
Buildroot: %{_tmppath}/%{name}-root
Prefix: /dev
Prereq: setup

%description
The Trustix operating system uses file system entries to represent
devices (CD-ROMs, floppy drives, etc.) attached to the machine. All of
these entries are in the /dev tree (although they don't have to be). 
This package contains the most commonly used /dev entries.  

The dev package is a basic part of your Trustix Secure Linux system and it
needs to be installed.

%prep
%setup -q -c -T

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf "$RPM_BUILD_ROOT"
mkdir -p $RPM_BUILD_ROOT
BUILD_DIR=`pwd`

# Make sure that group audio exists in the build machine
if [ -z "`getent group audio`" ]; then
        /usr/sbin/groupadd -r audio
fi

# unpack in build root
cd $RPM_BUILD_ROOT
tar xpSzf %{SOURCE0}

#Correct ownership for Audio devices
/bin/chown root:audio $RPM_BUILD_ROOT/dev/{dsp,mixer,midi}*
/bin/chown -R root:audio $RPM_BUILD_ROOT/dev/snd* 

cd $RPM_BUILD_ROOT/dev
# Add the cciss devices
tar xpSzf %{SOURCE1}


# tar doesn't save some permissions unless the p option is used
# this code protects against dev package updaters forgetting to
# use the p option when unpacking the souce tarball.
for dev in zero null tty ttyp0 ; do
  if [ ! $(ls -l $dev | awk '{print $1}') = crw-rw-rw- ] ; then
    echo bad permissions on device $dev 1>&2
    exit 1
  fi
done

# things we will not need because of obsoletion
rm -f isdnctrl
install -d -m 755 $RPM_BUILD_ROOT/dev/shm

# build the file list
cd $BUILD_DIR
(cd $RPM_BUILD_ROOT/dev; ls) | sed 's,^,/dev/,' | sed '{
  /\/dev\/log$/ s/^/%ghost /
  /\/dev\/shm$/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/fd..*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/fb.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/video.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/radio.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/winradio.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/vtx.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/vbi.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/kbd.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/audio.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/js.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/cua.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/dsp*.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/midi.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/mixer.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/sequencer/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/sndstat.*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/tty[SCDEIMR].*/ s/^/%verify(not group,mode,mtime) /
  /\/dev\/tty[a-z][!A-Z].$/ s/^/%verify(size) /
  /\/dev\/pty.*/ s/^/%verify(size) /
}'| sort -u > filelist
# that "size" should really be "maj,min" but rpm doesn't
# follow Maximum RPM's documentation of %verify...

%clean 
#[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf "$RPM_BUILD_ROOT"

%files -f filelist

%changelog
* Mon Feb 26 2007 Nived Gopalan <nived at trustix dot org>
- Rebuilt

* Mon Aug  7 2006 Bipin S <bipin at trustix dot com> 2.7.20-2tr
- Added /dev/shm.

* Tue Aug 23 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.7.20-1tr
- Added i2c nodes, Bug #1202.

* Tue Jun 28 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.7.19-8tr
- Added drbd* entries to /dev. Ref. Bug #815. 

* Thu Apr  7 2005 Chr. Toldnes <christht at trustix dot org> 2.7.19-6tr
- Removed audio groups, should be added to setup

* Wed Apr 06 2005 Syed S. Zakiullah <syedshabir at comodo dot com> 2.7.19-5tr
- Added audio group and changed ownership information for 
  /dev/{dsp,mixer,midi}* and /dev/snd*

* Wed Mar 23 2005 Syed S. Zakiullah <syedshabir at comodo dot com> 2.7.19-4tr
- Fixed Permission problem in /dev/{dsp,mixer,midi}* and /dev/snd*

* Wed Mar 16 2005 Raghu <raghu at comodo dot com> 2.7.19-3tr
- Rebuilt

* Fri Mar 11 2005 Chr. Toldnes <christht at trustix dot org> 2.7.19-1tr
- Don't use %pre or %post scripts

* Wed Feb 23 2005 Syed S. Zakiullah <syedshabir at comodo dot com> 2.7.19-1tr
- New Upstream contains /dev/osst*

* Thu Oct 28 2004 Syed Shabir <syedshabir at comodo dot com> 2.7.18-3tr
- Added extra-devices

* Tue Sep 21 2004 Syed Shabir <syedshabir at comodo dot com> 2.7.18-1tr
- New Upstream

* Fri Mar 26 2004 Oystein Viggen <oysteivi at trustix dot com> 2.7.11-9tr
- Removed %defattr

* Wed Mar  3 2004 Chr. Toldnes <christht at trustix dot org> 2.7.11-6tr
- Added cciss nodes

* Mon Dec 15 2003 Erlend Midttun <erlendbm at trustix dot org> 2.7.11-5tr
- Rebuilt.

* Mon Jun 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.7.11-4tr
- Added %defattr.

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2.7.11-3tr
- Big rebuild

* Mon May 26 2003 Erlend Midttun <erlendbm at trustix dot com> 2.7.11-2em
- fileutils, textutils -> coreutils.

* Fri May 23 2003 Erlend Midttun <erlendbm at trustix dot com> 2.7.11-1em
- Added /dev/md*

* Mon Mar 24 2003 Erlend Midttun <erlendbm at trustix dot com> 2.7.10-11em
- Rebuilt against glibc 2.3.2.

* Thu Feb 27 2003 Erlend Midttun <erlendbm at trustix dot com> 2.7.10-10em
- Fixed setup.
- Fixed getent.

* Thu Jul 18 2002 Roland Kruse <rolandk at trustix dot com> 2.7.10-9rk
- Remove groupadd on build machine - clean up groupadd in %pre

* Wed Jul 17 2002 Roland Kruse <rolandk at trustix dot com> 2.7.10-8rk
- Fixed groupadd commands - removed -f and -r options

* Tue Jul 16 2002 Christian H. Toldnes <christht at trustix dot com> 2.7.10-7ct
- simple rebuild to fit TSL 2.0

* Tue Apr 03 2001 Alexander Reelsen <ar at trustix dot com>
- Fixed dependency problems

* Wed Mar 01 2000 Lars Gaarden <larsg at trustix dot com>
- make sure that groups console and floppy are created
 
* Tue Sep 21 1999 Michael K. Johnson <johnsonm@redhat.com>
- now have first few of all types of v4l devices (MAKEDEV v4l for all of them)

* Mon Sep 20 1999 Michael K. Johnson <johnsonm@redhat.com>
- changed mouse and cdrom devices to not be world-readable (#4390)
- fixed some of the cdrom devices that weren't group disk

* Fri Sep 10 1999 Matt Wilson <msw@redhat.com>
- added /dev/video*

* Fri Sep 03 1999 Cristian Gafton <gafton@redhat.com>
- take out the /dev/isdnctrl (now in the isdn4k-utils package)

* Thu Aug 12 1999 Bill Nottingham <notting@redhat.com>
- remove /dev/printer

* Fri Jul 16 1999 Bill Nottingham <notting@redhat.com>
- fix perms on /dev/pts in tarball so it verifies OK

* Wed Jun  9 1999 Matt Wilson <msw@redhat.com>
- changed %post script to mount /dev/pts with the proper permissions

* Sat Apr 17 1999 Michael K. Johnson <johnsonm@redhat.com>
- added a great many devices, mostly from the 2.2 kernel,
  regularized some permissions

* Fri Apr 16 1999 Michael K. Johnson <johnsonm@redhat.com>
- now have all the sd* devices that are mentioned in Devices.txt

* Thu Apr 15 1999 Preston Brown <pbrown@redhat.com>
- joystick entries

* Thu Apr 15 1999 Michael K. Johnson <johnsonm@redhat.com>
- changed a requires line to a prereq line for the %post
- deal properly with fstab files with multiple proc entries

* Tue Apr 13 1999 Michael K. Johnson <johnsonm@redhat.com>
- /dev/kbd files will be managed by pam_console like /dev/fb

* Mon Apr 12 1999 Michael K. Johnson <johnsonm@redhat.com>
- /dev/fb devices are not sparc-specific and permissions will
  change as they are managed by pam_console by default.

* Fri Apr 09 1999 Michael K. Johnson <johnsonm@redhat.com>
- make sure permissions on /etc/fstab do not change while adding
  devpts filesystem

* Mon Mar 29 1999 Michael Johnson <johnsonm@redhat.com>
- added m68k devices from puffin

* Mon Mar 29 1999 Michael Johnson <johnsonm@redhat.com>
- fixed permissions on audio devices

* Sat Mar 27 1999 Cristian Gafton <gafton@redhat.com>
- added devices for Multitech IntelligentSerialInternal (isicom)

* Thu Mar 25 1999 Michael Johnson <johnsonm@redhat.com>
- added permission check so that careless tar use will not mangle permissions
- /dev/tty set to 666
- nb devices

* Tue Mar 23 1999 Michael Johnson <johnsonm@redhat.com>
- made /dev/zero world-writable again

* Sun Mar 21 1999 Matt Wilson <msw@redhat.com>
- added entries for DAC960 and Compaq Smart/2 RAID array controllers

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Fri Mar 19 1999 Michael Johnson <johnsonm@redhat.com>
- isdnctrl messy symlink fixed

* Tue Mar 09 1999 Michael Johnson <johnsonm@redhat.com>
- fixed logic for case when /etc/fstab does not exist

* Tue Feb 23 1999 Michael Johnson <johnsonm@redhat.com>
- added ptmx and pts, moved console to 5,1
  NB: we add devpts to /etc/fstab if it is not there; folks who
  for any reason don't want to use devpts should COMMENT OUT (not
  remove) the line and we will try not to add it again in the
  future.
- opened permissions back up on old-style ptys

* Tue Feb 23 1999 Matt Wilson <msw@redhat.com>
- yes, sparcs have IDE devices now, you *need* those devices.

* Mon Dec 14 1998 Michael K. Johnson <johnsonm@redhat.com>
- console-config is dead
- permission check limiting is still the right thing to do, though,
  for whatever replaces console-config

* Wed Dec 09 1998 Michael K. Johnson <johnsonm@redhat.com>
- moved dynamically configured to archive (changed to tar)
- added console-config.d file
- limited permission checking for files console-config manages
- permissions changed to console-config defaults

* Fri May 08 1998 Michael K. Johnson <johnsonm@redhat.com>
- added paride devices

* Tue May 05 1998 Erik Troan <ewt@redhat.com>
- uses a filelist
- ghosts /dev/log

* Fri May 01 1998 Cristian Gafton <gafton@redhat.com>
- fixed groupadd call in the %install

* Fri Apr 24 1998 Prospector System <bugs@redhat.com>
- translations modified for de

* Thu Apr 23 1998 Prospector System <bugs@redhat.com>
- translations modified for fr, tr

* Thu Apr 23 1998 Erik Troan <ewt@redhat.com>
- fixed preinstall script

* Tue Apr 21 1998 Erik Troan <ewt@redhat.com>
- updated groupadd to work with upgrades where the floppy group already exists

* Mon Nov 10 1997 Michael K. Johnson <johnsonm@redhat.com>
- Added more ramdisk entries

* Wed Oct 29 1997 Michael K. Johnson <johnsonm@redhat.com>
- Added fd and ramdisk symlinks

* Fri Oct 24 1997 Michael K. Johnson <johnsonm@redhat.com>
- Added floppy group for floppies; made them group-writable.

* Tue Jul 08 1997 Erik Troan <ewt@redhat.com>
- added bpcd device

* Thu Apr 10 1997 Erik Troan <ewt@redhat.com>
- Added ftape devices

* Tue Mar 25 1997 Erik Troan <ewt@redhat.com>
- Fixed stdin, stdout devices.
- Moved rtc to cpio archive
- Added ISDN devices

